# yzm_file

> **`File read and write operations`**

This is a simple log package. You can see
[Github-yzm_file](https://github.com/YuZhengM/yzm_file)
[PyPI-yzm_file](https://pypi.org/project/yzm_file/)

## Use

> install

```shell
pip install yzm_file
```

> import

```shell
import yzm_file as yf
```

